// --------------------------------------------------------------------------------
// MicroMighty Software Development Kit (SDK)
// --------------------------------------------------------------------------------
// Copyright By MicroMighty, Inc. All Rights Reserved.
//
// You can use this SDK for personal use only, any commercial use or use for other 
// type of organization including non profit on a production server is not allowed.
//
// You may not publish, sell, re-distribute, rent, lease or re-license any content
// contained in this source code and/or DLLs and/or other components of the SDK 
// without an explicit written permission agreement signed by MicroMighty, Inc.
//
// MicroMighty, Inc. reserves the right to permanently cancel without any warnings
// neither refund a license that is suspected of being used illegitimately or that
// violates the EULA (http://MicroMighty.com/Components/MicroMighty_SDK/EULA)
// --------------------------------------------------------------------------------

using System;
using System.Configuration;
using System.Collections;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Data;
using System.Net.Mail;
using System.Text;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using MicroMighty.SDK.Net.Tools;

public partial class Demo_Cache : System.Web.UI.Page
{
    #region Members

    private List<NameValueCollection> _nvcList;
    private string _cacheKeyCategory = "CacheObject";

    #endregion Members

    #region Events

    protected override void OnInit(EventArgs e)
    {
        base.OnInit(e);

        // This will read specific data for the first time and add a new cache object
        LoadDataByNameAndCacheIt("Colors", new TimeSpan(0, 1, 0)); // Cache it for 1 minute

        // This object is cached and it will be loaded from the cache this time
        LoadDataByNameAndCacheIt("Colors", new TimeSpan(0, 1, 0)); // Cache it for 1 minute

        // --------------------------------------------------------------------------------
        // Note: you can enumerate through all cache objects like this:
        // --------------------------------------------------------------------------------
        //IDictionaryEnumerator CacheEnum = EasyCache.GetEnumerator();
        //while (CacheEnum.MoveNext())
        //{
        //    // Do something with the current CacheEnum.Key.ToString()
        //}
    }

    #endregion Events

    #region Methods

    /// <summary>
    /// Get some records into a serializable list of object just for testing
    /// <para>(this can be any simple, complex data structure or just a string variable)</para>
    /// </summary>
    /// <param name="categoryName"></param>
    /// <returns></returns>
    private List<NameValueCollection> LoadDataByName(string categoryName)
    {
        List<NameValueCollection> nvcList = new List<NameValueCollection>();

        NameValueCollection nvc = new NameValueCollection();

        for (int i = 0; i < 5; i++) // Add values to the object
        {
            nvc.Add(categoryName + " - " + i.ToString(), categoryName + " - " + i.ToString());
        }

        for (int i = 0; i < 5; i++) // Add values to the List
        {
            nvcList.Add(nvc);
        }

        return (nvcList);
    }

    /// <summary>
    /// Get some test records using LoadDataByName() and also cache it
    /// <para>(Use EasyCache.AddAllMachines() to test with multiple machines)</para>
    /// </summary>
    /// <param name="categoryName"></param>
    /// <param name="cacheTime"></param>
    private void LoadDataByNameAndCacheIt(string categoryName, TimeSpan cacheTime)
    {
        DateTime cacheExpiration = DateTime.Now.Add(cacheTime);

        string _cacheKey = _cacheKeyCategory + EasyCache.Instance.Separator + categoryName;

        if (EasyCache.Instance.Exist(_cacheKey) && cacheTime != TimeSpan.Zero) // Load from cache
        {
            _nvcList = (List<NameValueCollection>)EasyCache.Instance.Item(_cacheKey);
        }
        else // Load and cache it
        {
            _nvcList = LoadDataByName(categoryName);
            EasyCache.Instance.Add(_cacheKey, _nvcList, cacheExpiration);

            if (EasyCache.Instance.Active)
            {
                foreach (NameValueCollection nvc in _nvcList) // Cache items in the list
                {
                    _cacheKey = _cacheKeyCategory + EasyCache.Instance.Separator + nvc.ToString();
                    EasyCache.Instance.Add(_cacheKey, nvc, cacheExpiration);
                }
            }
        }
    }

    #endregion Methods
}