' --------------------------------------------------------------------------------
' MicroMighty Software Development Kit (SDK)
' --------------------------------------------------------------------------------
' Copyright By MicroMighty, Inc. All Rights Reserved.
'
' You can use this SDK for personal use only, any commercial use or use for other 
' type of organization including non profit on a production server is not allowed.
'
' You may not publish, sell, re-distribute, rent, lease or re-license any content
' contained in this source code and/or DLLs and/or other components of the SDK 
' without an explicit written permission agreement signed by MicroMighty, Inc.
'
' MicroMighty, Inc. reserves the right to permanently cancel without any warnings
' neither refund a license that is suspected of being used illegitimately or that
' violates the EULA (http://MicroMighty.com/Components/MicroMighty_SDK/EULA)
' --------------------------------------------------------------------------------

Imports System
Imports System.Configuration
Imports System.Collections
Imports System.Collections.Generic
Imports System.Collections.Specialized
Imports System.Data
Imports System.Net.Mail
Imports System.Text
Imports System.Web
Imports System.Web.Security
Imports System.Web.UI
Imports System.Web.UI.HtmlControls
Imports System.Web.UI.WebControls
Imports System.Web.UI.WebControls.WebParts
Imports MicroMighty.SDK.Net.Tools

Partial Public Class Demo_CacheVB
    Inherits System.Web.UI.Page

    Private _nvcList As List(Of NameValueCollection)
    Private _cacheKeyCategory As String = "CacheObject"

    Protected Overloads Overrides Sub OnInit(ByVal e As EventArgs)
        MyBase.OnInit(e)

        ' This will read specific data for the first time and add a new cache object
        LoadDataByNameAndCacheIt("Colors", New TimeSpan(0, 1, 0)) ' Cache it for 1 minute

        ' This object is cached and it will be loaded from the cache this time
        LoadDataByNameAndCacheIt("Colors", New TimeSpan(0, 1, 0)) ' Cache it for 1 minute

        ' --------------------------------------------------------------------------------
        ' Note: you can enumerate through all cache objects like this:
        ' --------------------------------------------------------------------------------
        'Dim CacheEnum As IDictionaryEnumerator = EasyCache.GetEnumerator()
        'While CacheEnum.MoveNext()
        '    // Do something with the current CacheEnum.Key.ToString()
        'End While

    End Sub

    ''' <summary>
    ''' Get some records into a serializable list of object just for testing
    ''' <para>(this can be any simple, complex data structure or just a string variable)</para>
    ''' </summary>
    ''' <param name="categoryName"></param>
    ''' <returns></returns>
    Private Function LoadDataByName(ByVal categoryName As String) As List(Of NameValueCollection)
        Dim nvcList As New List(Of NameValueCollection)()

        Dim nvc As New NameValueCollection()

        Dim i As Integer = 0
        While i < 5
            ' Add values to the object
            nvc.Add(categoryName + " - " + i.ToString(), categoryName + " - " + i.ToString())
            System.Math.Max(System.Threading.Interlocked.Increment(i), i - 1)
        End While

        i = 0
        While i < 5
            ' Add values to the List
            nvcList.Add(nvc)
            System.Math.Max(System.Threading.Interlocked.Increment(i), i - 1)
        End While

        Return (nvcList)
    End Function

    ''' <summary>
    ''' Get some test records using LoadDataByName() and also cache it
    ''' <para>(Use EasyCache.AddAllMachines() to test with multiple machines)</para>
    ''' </summary>
    ''' <param name="categoryName"></param>
    ''' <param name="cacheTime"></param>
    Private Sub LoadDataByNameAndCacheIt(ByVal categoryName As String, ByVal cacheTime As TimeSpan)
        Dim cacheExpiration As DateTime = DateTime.Now.Add(cacheTime)

        Dim _cacheKey As String = _cacheKeyCategory + EasyCache.Instance.Separator + categoryName

        If EasyCache.Instance.Exist(_cacheKey) AndAlso cacheTime <> TimeSpan.Zero Then
            ' Load from cache
            _nvcList = DirectCast(EasyCache.Instance.Item(_cacheKey), List(Of NameValueCollection))
        Else
            ' Load and cache it
            _nvcList = LoadDataByName(categoryName)
            EasyCache.Instance.Add(_cacheKey, _nvcList, cacheExpiration)

            If EasyCache.Instance.Active Then
                For Each nvc As NameValueCollection In _nvcList
                    ' Cache items in the list
                    _cacheKey = _cacheKeyCategory + EasyCache.Instance.Separator + nvc.ToString()
                    EasyCache.Instance.Add(_cacheKey, nvc, cacheExpiration)
                Next
            End If
        End If
    End Sub

End Class