// --------------------------------------------------------------------------------
// MicroMighty Software Development Kit (SDK)
// --------------------------------------------------------------------------------
// Copyright By MicroMighty, Inc. All Rights Reserved.
//
// You can use this SDK for personal use only, any commercial use or use for other 
// type of organization including non profit on a production server is not allowed.
//
// You may not publish, sell, re-distribute, rent, lease or re-license any content
// contained in this source code and/or DLLs and/or other components of the SDK 
// without an explicit written permission agreement signed by MicroMighty, Inc.
//
// MicroMighty, Inc. reserves the right to permanently cancel without any warnings
// neither refund a license that is suspected of being used illegitimately or that
// violates the EULA (http://MicroMighty.com/Components/MicroMighty_SDK/EULA)
// --------------------------------------------------------------------------------

using System;
using System.Configuration;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Net.Mail;
using System.Text;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using MicroMighty.SDK.Net.Tools;

public partial class Demo_Send : System.Web.UI.Page
{
    #region Members

    #endregion Members

    #region Properties

    #endregion Properties

    #region Events

    protected override void OnInit(EventArgs e)
    {
        base.OnInit(e);

        LoadDefaultSMTPValues();

        // Disable the button once its clicked to avoid clicking it more than once
        _buttonSend.Attributes.Add("onClick", "this.disabled=true; " +
            Page.ClientScript.GetPostBackEventReference(_buttonSend, null) + "; " +
            "return(false);");
    }

    protected void _buttonSend_Click(object sender, EventArgs e)
    {
        EasyEmailSender ees = new EasyEmailSender();

        // Load the email object with the current SMTP variables (for testing)
        try { ees.SMTPEnableSSL = Convert.ToBoolean(_textBoxSMTPEnableSSL.Text); } catch { ees.SMTPEnableSSL = false; }
        try { ees.SMTPPort = Convert.ToInt32(_textBoxSMTPPort.Text); } catch { ees.SMTPPort = 25; }
        ees.SMTPHost = _textBoxSMTPHost.Text;
        ees.SMTPUserName = _textBoxSMTPUserName.Text;
        ees.SMTPPassword = _textBoxSMTPPassword.Text;

        ees.AddressFrom = new MailAddress(_textBoxFromEmail.Text, _textBoxFromName.Text, ees.AddressEncoding);
        ees.AddressReplyTo = ees.AddressFrom;

        // More email users can be copied using AddressesTo.Add, AddressesCC and the AddressesBCC properties
        ees.AddressesTo.Add(new MailAddress(_textBoxToEmail.Text, _textBoxToName.Text, ees.AddressEncoding));
        
        ees.Subject = _textBoxSubject.Text + " (Reference ID " + ees.ReferenceIDFriendly + ")";
        ees.Body = _textBoxMessage.Text.Replace("\r\n", "<br />");
        ees.Priority = MailPriority.Normal;

        if (ees.Send())
        {
            _sendResult.ForeColor = System.Drawing.Color.DarkGreen;
            _sendResult.Text = "The email was sent successfully (Reference ID " + ees.ReferenceIDFriendly + ")";

            ClearFormFields();
        }
        else
        {
            _sendResult.ForeColor = System.Drawing.Color.DarkRed;
            _sendResult.Text = "Send failed - " + ees.ErrorMessage;
        }
    }

    protected void _buttonClear_Click(object sender, EventArgs e)
    {
        LoadDefaultSMTPValues();

        ClearFormFields();

        _sendResult.ForeColor = System.Drawing.Color.Gray;
        _sendResult.Text = "N/A";
    }

    #endregion Events

    #region Methods

    /// <summary>
    /// Load default SMTP variables from Web.Config
    /// </summary>
    private void LoadDefaultSMTPValues()
    {
        _textBoxSMTPEnableSSL.Text = Globals.EasyEmailSenderSMTPEnableSSL.ToString().ToLower();
        _textBoxSMTPPort.Text = Globals.EasyEmailSenderSMTPPort.ToString();
        _textBoxSMTPHost.Text = Globals.EasyEmailSenderSMTPHost;
        _textBoxSMTPUserName.Text = Globals.EasyEmailSenderSMTPUserName;
        _textBoxSMTPPassword.Text = Globals.EasyEmailSenderSMTPPassword;
    }

    /// <summary>
    /// Clear form fields
    /// </summary>
    private void ClearFormFields()
    {
        _textBoxFromName.Text = "";
        _textBoxFromEmail.Text = "";
        _textBoxToName.Text = "";
        _textBoxToEmail.Text = "";
        _textBoxSubject.Text = "";
        _textBoxMessage.Text = "";
    }

    #endregion Methods
}